/**
 * @file
 * Provides Intense loader.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Intense utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} elm
   *   The Intense gallery HTML element.
   */
  function doIntense(i, elm) {
    var $elm = $(elm);
    var hasMedia = $('.media--video', elm).length;

    if (hasMedia && Drupal.blazyBox) {
      Drupal.blazyBox.attach();
    }

    /**
     * Intense utility functions.
     *
     * @param {Event} e
     *   The event triggering the Intense.
     */
    function triggerIntense(e) {
      // The e.target points to an IMG, and e.currentTarget (jQuery) to A tag.
      var $link = $(e.currentTarget);
      var $img = $('img', $link);
      var media = $link.data('media') || {};
      var video = media && media.type === 'video';

      // Build own video fullscreen as Intense is not for video.
      if (video && Drupal.blazyBox) {
        Drupal.blazyBox.open($link.attr('href'));
      }
      else {
        new Intense($img[0]);
      }

      e.preventDefault();
    }

    $elm.on('click', '[data-intense-trigger]', triggerIntense);
  }

  /**
   * Attaches Intense behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.intense = {
    attach: function (context) {
      $('[data-intense-gallery]', context).once('intense-gallery', doIntense);
    }
  };

})(jQuery, Drupal);
